;; Generated package description from geiser-gambit.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "geiser-gambit" "0.18.1.0.20260727.2" "Gambit's implementation of the geiser protocols" '((emacs "26.1") (geiser "0.18")) :commit "70e3d90b123221f8a09f3bc9a53fba1a968bf104" :maintainer '("Jose A Ortega Ruiz" . "jao@gnu.org") :keywords '("languages" "gambit" "scheme" "geiser") :url "https://gitlab.com/emacs-geiser/gambit")
